#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @File    :   fedhf\api\type\const.py
# @Time    :   2022-02-13 14:24:10
# @Author  :   Bingjie Yan
# @Email   :   bj.yan.pa@qq.com
# @License :   Apache License 2.0


class DefaultConst(object):
    pass